<?php

// Reminder: always indent with 4 spaces (no tabs). 
// +---------------------------------------------------------------------------+
// | Archive plugin 1.2 for Geeklog                                            |
// +---------------------------------------------------------------------------+
// | functions.inc                                                             |
// |                                                                           |
// | This file installs and removes the data structures for the                |
// | Archive plugin for Geeklog.                                               |
// +---------------------------------------------------------------------------+
// | Based on the Universal Plugin and prior work by the following authors:    |
// |                                                                           |
// | Copyright (C) 2002-2007 by the following authors:                         |
// |                                                                           |
// | Authors: Euan McKay        - info AT heatherengineering DOT com           |
// |          Tony Bibbs        - tony AT tonybibbs DOT com                    |
// |          Tom Willett       - tom AT pigstye DOT net                       |
// |          Blaine Lang       - blaine AT portalparts DOT com                |
// |          Dirk Haun         - dirk AT haun-online DOT de                   |
// |          Vincent Furia     - vinny01 AT users DOT sourceforge DOT net     |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//


if (strpos ( $_SERVER['PHP_SELF'], 'functions.inc' ) !== false) {
    die ( 'This file can not be used on its own.' );
}

$langfile = $_CONF['path'] . 'plugins/archive/language/' . $_CONF['language'] . '.php';

if (file_exists( $langfile )) {
    require_once( $langfile );
} else {
    require_once( $_CONF['path'] . 'plugins/archive/language/english.php' );
}

require_once( $_CONF['path'] . 'plugins/archive/config.php' );
require_once( $_CONF['path'] . 'plugins/archive/plugins.php' );
require_once( $_CONF['path'] . 'plugins/archive/archivetypes.php' );



// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementation                                         |
// +---------------------------------------------------------------------------+

/**
* Returns the items for this plugin that should appear on the main menu
*
* NOTE: this MUST return the url/value pairs in the following format
* $<arrayname>[<label>] = <url>
*
* @return   mixed   menu entry, or boolean false if disabled / hidden
*
*/
function plugin_getmenuitems_archive()
{
	global $LANG_AR, $_CONF;
    return array($LANG_AR[14] => $_CONF['site_url'] . '/archive/index.php');
}

/**
* This will put an option for archives in the command and control block on
* moderation.php
*
* @return   mixed   array(title, url, icon), or boolean false when not allowed
*
*/
function plugin_cclabel_archive()
{
    global $_CONF, $LANG_AR;

    if (SEC_hasRights('archive.edit')) {
        return array ($LANG_AR[14],
                      $_CONF['site_admin_url'] . '/plugins/archive/index.php',
                      plugin_geticon_archive ());
    }

    return false;
}

/**
* returns the administrative option for this plugin
*
* @return   mixed   array(title, url, num. archive), or void when not allowed
*
*/
function plugin_getadminoption_archive()
{
    global $_CONF, $_TABLES, $LANG_AR;

    if (SEC_hasRights('archive.edit')) {
        $total_archive = DB_getItem ($_TABLES['archive'], 'COUNT(*)',
                                   COM_getPermSql (''));

        return array ($LANG_AR[14],
                      $_CONF['site_admin_url'] . '/plugins/archive/index.php',
                      $total_archive);
    }
}


/**
* Return headlines for New archive section in the What's New block, if enabled
*
* @return   mixed       array(headline, byline), or boolean false is disabled
*
*/
function plugin_whatsnewsupported_archive()
{
    return false;
}


/**
* Called by the plugin Editor to display the current plugin code version
* This may be different than the version installed and registered currently.
* If newer then you may want to run the update
*
* @return   string  version number
*
*/
function plugin_chkVersion_archive ()
{
    global $_AR_CONF;

    return $_AR_CONF['version'];
}

/**
* Helper function: count number of archive and total number of clicks
*
* @return   array(number of archive, number of clicks);
*
*/
function archive_countarchivesAndClicks ()
{
    global $_TABLES;

    $result = DB_query("SELECT COUNT(*) AS count,SUM(hits) AS clicks FROM {$_TABLES['archive']}" . COM_getPermSQL ());
    $A = DB_fetchArray ($result);
    $total_archive = $A['count'];
    $total_clicks = $A['clicks'];
    if (empty ($total_clicks)) {
        $total_clicks = 0;
    }

    return array ($total_archive, $total_clicks);
}

/**
* Get header code for inclusion
*
* @return   string
*
*/
function plugin_getheadercode_archive()
{
    global $_CONF;
    $url = $_CONF['site_url']."/archive/archive.css";
    $jurl = $_CONF['site_url']."/archive/javascript/";
    return '<!-- archive CSS include -->
<style type="text/css">
@import "'.$url.'";
</style>
<script type="text/javascript" src="'.$jurl.'documents.js"></script>
<script type="text/javascript" src="'.$jurl.'prototype.js"></script>
<script type="text/javascript" src="'.$jurl.'scriptaculous.js"></script>';
}


/**
* Autotag support
*/
function plugin_autotags_archive ($op, $content = '', $autotag = '')
{
    global $_CONF, $_TABLES;

    if ($op == 'tagname' ) {
        return 'archive';
    } else if ($op == 'parse') {
        $id = COM_applyFilter ($autotag['parm1']);
        $url = COM_buildUrl ($_CONF['site_url']
                             . '/archive/index.php?id=' . $id);
        if (empty ($autotag['parm2'])) {
            $linktext = stripslashes (DB_getItem ($_TABLES['archive'],
                                      'title', "id = '$id'"));
        } else {
            $linktext = $autotag['parm2'];
        }
        $link = '<a href="' . $url . '">' . $linktext . '</a>';
        $content = str_replace ($autotag['tagstr'], $link, $content);

        return $content;
    }
}



// +---------------------------------------------------------------------------+
// | Geeklog Statistics                                                        |
// +---------------------------------------------------------------------------+

/**
* Shows the statistics for the archive plugin on stats.php.
* If $showsitestats is 1 then we are to only print the overall stats in the
* 'site statistics box' otherwise we show the detailed stats
*
* @param    int     $showsitestate  Flag to let us know which stats to get
* @param    string                  HTML for the stats section
*
*/
function plugin_showstats_archive ($showsitestats)
{
    global $_CONF, $_TABLES, $LANG_AR_STATS;

    require_once ($_CONF['path_system'] . 'lib-admin.php');

    $retval = '';

    $result = DB_query("SELECT id,title,hits FROM {$_TABLES['archive']} WHERE (hits > 0)" . COM_getPermSQL ('AND') . " ORDER BY hits DESC LIMIT 10");
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $header_arr = array(
            array('text'         => $LANG_AR_STATS['stats_page_title'],
                  'field'        => 'sid',
                  'header_class' => 'stats-header-title'
            ),
            array('text'         => $LANG_AR_STATS['stats_hits'],
                  'field'        => 'hits',
                  'header_class' => 'stats-header-count',
                  'field_class'  => 'stats-list-count'
            )
        );
        $data_arr = array();
        $text_arr = array('has_menu' => false,
                          'title'    => $LANG_AR_STATS['stats_headline'],
        );
        for ($i = 0; $i < $nrows; $i++) {
            $A = DB_fetchArray ($result);
            $title = stripslashes (str_replace ('$', '&#36;', $A['title']));
            $url = COM_buildUrl ($_CONF['site_url']
                        . '/archive/index.php?id=' . $A['id']);
            $sid = '<a href="' . $url . '" title="' . $A['title'] . '">' . $title
                 . '</a>';
            $hits = COM_numberFormat ($A['hits']);
            $data_arr[] = array('title' => $title,
                                'sid' => $sid,
                                'hits' => $hits
                          );
        }
        $retval .= ADMIN_simpleList ('', $header_arr, $text_arr, $data_arr);
    } else {
        $retval .= COM_startBlock($LANG_AR_STATS['stats_headline']);
        $retval .= $LANG_AR_STATS['stats_no_hits'];
        $retval .= COM_endBlock();
    }

    return $retval;
}

/**
* New stats plugin API function for proper integration with the site stats
*
* @return   array(item text, item count);
*
*/
function plugin_statssummary_archive ()
{
    global $LANG_AR_STATS;

    list($archives, $clicks) = archive_countarchivesAndClicks ();

    $item_count = COM_NumberFormat ($archives)
                . ' (' . COM_NumberFormat ($clicks) . ')';

    return array ($LANG_AR_STATS['archive'], $item_count);
}

// +---------------------------------------------------------------------------+
// | Geeklog Search                                                            |
// +---------------------------------------------------------------------------+

/**
* Geeklog is asking us to provide any items that show up in the type
* drop-down on search.php.  Let's users search for archives.
*
* @return   array   (plugin name/entry title) pair for the dropdown
*
*/
function plugin_searchtypes_archive()
{
    global $LANG_AR;

    $tmp['archive'] = $LANG_AR[14];

    return $tmp;
}


/**
* This searches for archives matching the user query and returns an array for the
* header and table rows back to search.php where it will be formated and printed
*
* @param    string  $query      Keywords user is looking for
* @param    date    $datestart  Start date to get results for
* @param    date    $dateend    End date to get results for
* @param    string  $topic      The topic they were searching in
* @param    string  $type       Type of items they are searching, or 'all'
* @param    int     $author     Get all results by this author
* @param    string  $keyType    search key type: 'all', 'phrase', 'any'
* @param    int     $page       page number of current search
* @param    int     $perpage    number of results per page
* @return   object              search result object
*
*/
function plugin_dopluginsearch_archive($query, $datestart, $dateend, $topic, $type, $author, $keyType, $page, $perpage)
{
    global $_CONF, $_TABLES, $LANG_AR_SEARCH, $LANG_AR;

    if (empty ($type)) {
        $type = 'all';
    }

    // Bail if we aren't supppose to do our search
    if ($type <> 'all' AND $type <> $LANG_AR[14]) {
        $plugin_results = new Plugin();
        $plugin_results->plugin_name = 'archive';
        $plugin_results->searchlabel = $LANG_AR_SEARCH['results'];

        return $plugin_results;
    }

    $select = 'SELECT a.id as id, a.title as title, a.owner_id as owner_id,'
            . 'a.hits as hits, UNIX_TIMESTAMP(a.modified) AS day,'
            . 't.title as text_title, t.content as text_content, t.textid as text_id';
    $sql    = " FROM {$_TABLES['archive']} AS a "
            . " LEFT JOIN {$_TABLES['archive_text']} AS t "
            . " ON a.id=t.parent WHERE modified <> 1 ";

    if (!empty ($query)) {
        if ($keyType == 'phrase') {
            $mysearchterm = addslashes ($query);
            $sql .= " AND (a.description LIKE '%$mysearchterm%')"
                 . " OR (a.title LIKE '%$mysearchterm%')"
                 . " OR (t.title LIKE '%$mysearchterm%')"
                 . " OR (t.content LIKE '%$mysearchterm%')";
        } else if ($keyType == 'all') {
            $mywords = explode (' ', $query);
            $sql .= " AND (";
            $tmp = '';
            foreach ($mywords AS $mysearchterm) {
                $mysearchterm = addslashes (trim ($mysearchterm));
                if (!empty ($mysearchterm)) {
                    $tmp .= "(a.description LIKE '%$mysearchterm%')"
                         . " OR (a.title LIKE '%$mysearchterm%')"
                         . " OR (t.title LIKE '%$mysearchterm%')"
                         . " OR (t.content LIKE '%$mysearchterm%') AND ";
                }
            }
            $tmp = substr ($tmp, 0, strlen ($tmp) - 5);
            $sql .= $tmp . ")";
        } else if ($keyType == 'any') {
            $mywords = explode (' ', $query);
            $sql .= " AND (";
            $tmp = '';
            foreach ($mywords AS $mysearchterm) {
                $mysearchterm = addslashes (trim ($mysearchterm));
                if (!empty ($mysearchterm)) {
                    $tmp .= "(a.description LIKE '%$mysearchterm%')"
                         . " OR (a.title LIKE '%$mysearchterm%')"
                         . " OR (t.title LIKE '%$mysearchterm%')"
                         . " OR (t.content LIKE '%$mysearchterm%') OR ";
                }
            }
            $tmp = substr ($tmp, 0, strlen ($tmp) - 4);
            $sql .= $tmp . ")";
        } else {  // quick search
            $mysearchterm = addslashes ($query);
            $sql .= " AND (a.description LIKE '%$mysearchterm%')"
                 . " OR (a.title LIKE '%$mysearchterm%')"
                 . " OR (t.title LIKE '%$mysearchterm%')"
                 . " OR (t.content LIKE '%$mysearchterm%')";
        }
    }

    if (!empty ($datestart) && !empty ($dateend)) {
        $delim = substr ($datestart, 4, 1);
        if (!empty($delim)) {
            $DS = explode ($delim, $datestart);
            $DE = explode ($delim, $dateend);
            $startdate = mktime (0, 0, 0, $DS[1], $DS[2], $DS[0]);
            $enddate = mktime (23, 59, 59, $DE[1], $DE[2], $DE[0]);
            $sql .= " AND (UNIX_TIMESTAMP(modified) BETWEEN '{$startdate}' AND '{$enddate}')";
        }
    }

    if (!empty ($author)) {
        $sql .= " AND (a.owner_id = '{$author}')";
    }
    $sql .= COM_getPermSQL ('AND');
    $sql .= " GROUP BY a.modified, a.id, a.description, a.title, a.hits, a.owner_id, a.group_id, a.perm_owner, a.perm_group, a.perm_members, a.perm_anon ORDER BY a.modified DESC";
    $l = ($perpage * $page) - $perpage;
    $sql .= " LIMIT " . $l . "," . $perpage;

    // Perform search
    $result = DB_query($select . $sql);
    $mycount = DB_numRows ($result);
    $result_count = DB_query('SELECT COUNT(*)' . $sql);
    $B = DB_fetchArray ($result_count, true);

    $plugin_results = new Plugin();
    $plugin_results->plugin_name = 'archive';
    $plugin_results->searchlabel = $LANG_AR_SEARCH['results'];
    $plugin_results->addSearchHeading ($LANG_AR_SEARCH['title']);
    $plugin_results->addSearchHeading ($LANG_AR_SEARCH['modified']);
    $plugin_results->addSearchHeading ($LANG_AR_SEARCH['author']);
    $plugin_results->addSearchHeading ($LANG_AR_SEARCH['hits']);
    $plugin_results->num_searchresults = 0;
    $plugin_results->num_itemssearched = $B[0];
    $plugin_results->supports_paging = true;

    // NOTE if any of your data items need to be archives then add them here!
    // make sure data elements are in an array and in the same order as your
    // headings above!
    for ($i = 0; $i < $mycount; $i++) {
        $A = DB_fetchArray ($result);

        $thetime = COM_getUserDateTimeFormat ($A['modified']);
        $A['title'] = stripslashes ($A['title']);
        $submitter = COM_getDisplayName ($A['owner_id']);
        if ($A['owner_id'] > 1) {
            $profile = '<a href="' . $_CONF['site_url']
                     . '/users.php?mode=profile&amp;uid=' . $A['owner_id']
                     . '">' . $submitter . '</a>';
        } else {
            $profile = $submitter;
        }
        $archiveUrl = COM_buildURL ($_CONF['site_url']
                                 . '/archive/index.php?id='
                                 . $A['id']);
        $anchor = '<a href="' . $archiveUrl . '" title="' . $A['title'] . '">';
        $row = array ($anchor . $A['title'] . '</a>', $thetime[0], $profile,
                      COM_NumberFormat ($A['hits']));
        $plugin_results->addSearchResult ($row);
        $plugin_results->num_searchresults++;
    }

    return $plugin_results;
}


// +---------------------------------------------------------------------------+
// | Geeklog User Management                                                   |
// +---------------------------------------------------------------------------+

/**
* A user is about to be deleted. Update ownership of any archives owned
* by that user or delete them.
*
* @param    int     $uid    User id of deleted user
* @return   void
*
*/
function plugin_user_delete_archive ($uid)
{
    global $_TABLES, $_LI_CONF;

    if (DB_count($_TABLES['archive'], 'owner_id', $uid) == 0) {
        return;
    }

    if ($_GN_CONF['delete_archive'] == 1) {
        // delete the archive
        DB_query("DELETE FROM {$_TABLES['archive']} WHERE owner_id={$uid}");
    } else {
        // assign ownership to a user from the Root group
        $rootgroup = DB_getItem ($_TABLES['groups'], 'grp_id', "grp_name = 'Root'");
        $result = DB_query("SELECT DISTINCT ug_uid 
                             FROM {$_TABLES['group_assignments']} 
                             WHERE ug_main_grp_id={$rootgroup} 
                             ORDER BY ug_uid 
                             LIMIT 1");
        $A = DB_fetchArray ($result);
        $rootuser = $A['ug_uid'];
        DB_query("UPDATE {$_TABLES['archive']} SET owner_id={$rootuser} WHERE owner_id={$uid}");
    }
}



// +---------------------------------------------------------------------------+
// | Feeds                                                                     |
// +---------------------------------------------------------------------------+

/**
* We support feeds for top level archive items
*
* @return   array   id/name pairs of all supported feeds
*
*/
function plugin_getfeednames_archive()
{
    global $_TABLES;

    $feeds = array ();

    $result = DB_query("SELECT title 
                         FROM {$_TABLES['archive']} 
                         WHERE parent=0
                         ORDER BY title ASC");
    $num = DB_numRows ($result);

    if ($num > 0) {
        $feeds[] = array ('id' => 'all', 'name' => 'All categories');

        for ($i = 0; $i < $num; $i++) {
            $A = DB_fetchArray ($result);
            $feeds[] = array ('id' => $A['title'], 'name' => $A['title']);
        }
    }

    return $feeds;
}

/**
* Provide feed data
*
* @param    int     $feed       feed ID
* @param    ref     $archive
* @param    ref     $update
* @return   array               feed entries
*
*/
function plugin_getfeedcontent_archive ($feed, &$archive, &$update)
{
    global $_CONF, $_TABLES;

    $result = DB_query( "SELECT topic,limits,content_length FROM {$_TABLES['syndication']} WHERE fid = '$feed'" );
    $S = DB_fetchArray( $result );

    $result = DB_query( "SELECT id,owner_id,title,description,UNIX_TIMESTAMP(modified) AS modified FROM " . $_TABLES['archive'] . archive_buildSql ($S['topic'], $S['limits']) );

    $content = array();
    $ids = array();
    $nrows = DB_numRows( $result );

    for( $i = 0; $i < $nrows; $i++ )
    {
        $row = DB_fetchArray( $result );
        $ids[] = $row['id'];

        $archivetitle = stripslashes( $row['title'] );
        $archivedesc = stripslashes( $row['description'] );

        $archivelink = COM_buildUrl( $_CONF['site_url']
                  . '/archive/index.php?id=' . $row['id'] );

        $content[] = array( 'title'   => $archivetitle,
                            'summary' => $archivedesc,
                            'archive' => $archivelink,
                            'uid'     => $row['owner_id'],
                            'author'  => COM_getDisplayName( $row['owner_id'] ),
                            'modified'=> $row['modified'],
                            'format'  => 'plaintext'
                          );
    }

    $archive = $_CONF['site_url'] . '/archive/index.php';
    $update = implode( ',', $ids );

    return $content;
}

/**
* Helper function: Build part of an SQL request
*
* @param    string  $category   category name
* @param    string  $limits     limit (number of entries or number of hours)
* @return   string              part of an SQL request
*
*/
function archive_buildSql ($category, $limits)
{
    $where = '';
    if ($category != 'all') {
        $where = "category='" . $category . "'";
    }

    $limitsql = '';
    if (!empty ($limits)) {
        if (substr ($limits, -1) == 'h') { // last xx hours
            $limitsql = '';
            $hours = substr ($limits, 0, -1);
            if (!empty ($where)) {
                $where .= ' AND ';
            }
            $where .= "date >= DATE_SUB(NOW(),INTERVAL $hours HOUR)";
        } else {
            $limitsql = ' LIMIT ' . $limits;
        }
    }
    else
    {
        $limitsql = ' LIMIT 10';
    }

    if (!empty ($where)) {
        $where = ' WHERE ' . $where;
    }

    $sql = $where . ' ORDER BY modified DESC' . $limitsql;

    return $sql;
}

/**
* Checking if archive feeds are up to date
*
* @param    int     $feed           id of feed to be checked
* @param    string  $topic          topic (actually: category)
* @param    string  $update_data    data describing current feed contents
* @param    string  $limit          number of entries or number of hours
* @param    string  $updated_type   (optional) type of feed to be updated
* @param    string  $updated_topic  (optional) feed's "topic" to be updated
* @param    string  $updated_id     (optional) id of entry that has changed
* @return   boolean                 true: feed data is up to date; false: isn't
*
*/
function plugin_feedupdatecheck_archive ($feed, $topic, $update_data, $limit, $updated_type = '', $updated_topic = '', $updated_id = '')
{
    global $_TABLES;

    $is_current = true;

    if ($updated_type != 'archive') {
        // we're not interested
        $updated_type = '';
        $updated_topic = '';
        $updated_id = '';
    }

    $sql = "SELECT id FROM {$_TABLES['archive']}" . archive_buildSql ($topic, $limit);
    $result = DB_query($sql);
    $num = DB_numRows ($result);

    $ids = array ();
    for ($i = 0; $i < $num; $i++) {
        $A = DB_fetchArray ($result);

        if ($A['id'] == $updated_id) {
            // this feed has to be updated - no further checks needed
            return false;
        }

        $ids[] = $A['id'];
    }
    $current = implode (',', $ids);

    return ($current != $update_data) ? false : true;
}


// +---------------------------------------------------------------------------+
// | Plugin Control                                                            |
// +---------------------------------------------------------------------------+

/**
* Update the archives plugin
*
* @return   int     Number of message to display (true = generic success msg)
*
*/ 
function plugin_upgrade_archive ()
{
    global $_TABLES, $_AR_CONF;
    DB_query("UPDATE {$_TABLES['plugins']} SET pi_version = '{$_AR_CONF['version']}', pi_gl_version='" . VERSION . "' WHERE pi_name='archive'");
    return true;
}

/**
* Geeklog informs us that we're about to be enabled or disabled
* 
* @param    boolean     $enable     true = we're being enabled, false = disabled
* @return   void
*
*/
function plugin_enablestatechange_archive ($enable)
{
    global $_TABLES;

    $is_enabled = $enable ? 1 : 0;

    // toggle archive feeds
    DB_query("UPDATE {$_TABLES['syndication']} SET is_enabled = $is_enabled WHERE type = 'archive'");
}

/**
* Removes the datastructures for this plugin from the Geeklog database
*
* This may get called by the install routine to undo anything done to this
* point.
*
* @return   boolean     true: uninstalled successfully
*
*/
function plugin_uninstall_archive ()
{
    global $_CONF, $_TABLES;

    // Uninstalls the archive plugin

    // Remove the archive tables
    COM_errorLog('Dropping archive table', 1);
    DB_query("DROP TABLE {$_TABLES['archive']}");
    COM_errorLog('...success', 1);
    COM_errorLog('Dropping archive_text table', 1);
    DB_query("DROP TABLE {$_TABLES['archive_text']}");
    COM_errorLog('...success', 1);
    COM_errorLog('Dropping archive_address table', 1);
    DB_query("DROP TABLE {$_TABLES['archive_address']}");
    COM_errorLog('...success', 1);
    COM_errorLog('Dropping archive_related table', 1);
    DB_query("DROP TABLE {$_TABLES['archive_related']}");
    COM_errorLog('...success', 1);

    // Remove feed files
    COM_errorLog('removing archive feed files', 1);
    $sql = "SELECT filename FROM {$_TABLES['syndication']} WHERE type = 'archive';";
    $result = DB_query( $sql );
    $nrows = DB_numRows( $result );
    COM_errorLog($nrows. ' files stored in table.', 1);
    if ( $nrows > 0 ) {
        for ( $i = 0; $i < $nrows; $i++ ) {
            $fcount = $i + 1;
            $A = DB_fetchArray( $result );
            $fullpath = SYND_getFeedPath( $A[0] );
            if ( file_exists( $fullpath ) ) {
                unlink ($fullpath);
                COM_errorLog("removed file $fcount of $nrows: $fullpath", 1);
            } else {
                COM_errorLog("cannot remove file $fcount of $nrows, it does not exist! ($fullpath)", 1);
            }
        }
    }
    COM_errorLog('...success', 1);

    // Remove archive Feeds from syndiaction table
    COM_errorLog('removing archive feeds from table', 1);
    DB_query("DELETE FROM {$_TABLES['syndication']} WHERE type = 'archive'");
    COM_errorLog('...success', 1);

    // Remove security for this plugin

    // Remove the archive admin group
    $grp_id = DB_getItem ($_TABLES['groups'], 'grp_id',
                          "grp_name = 'Archive Admin'");

    if (!empty ($grp_id)) {
        COM_errorLog('Attempting to remove the archive Admin group', 1);
        DB_query("DELETE FROM {$_TABLES['groups']} WHERE grp_id = $grp_id");
        COM_errorLog('...success', 1);
    }

    // Remove related features
    $edit_id = DB_getItem ($_TABLES['features'], 'ft_id',
                           "ft_name = 'archive.edit'");

    // Remove access to those features
    if (!empty ($edit_id)) {
        COM_errorLog('Attempting to remove archive.edit rights from all groups' ,1);
        DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $edit_id");
        COM_errorLog('...success', 1);
    }

    // Remove archive Admin group from all other groups
    if (!empty ($grp_id)) {
        COM_errorLog('Attempting to archive Admin group from all groups.', 1);
        DB_query("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $grp_id");
        COM_errorLog('...success', 1);
    }

    // remove features
    if (!empty ($edit_id)) {
        COM_errorLog('Attempting to remove the archive.edit feature', 1);
        DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $edit_id");
        COM_errorLog('...success', 1);
    }


    // Unregister the plugin with Geeklog
    // Always attempt to remove these entries or lib-common.php would still
    // try and read our functions.inc file ...
    COM_errorLog('Attempting to unregister the plugin from Geeklog', 1);
    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'archive'");
    COM_errorLog('...success',1);

    COM_errorLog('Finished uninstalling the archive plugin.', 1);

    return true;
}


/**
* Return a list of all archives
*
* @param    ref     $current_category   currently selected category
* @return   string                      <option> list containing all categories
*
*/
function plugin_getListField_archive($fieldname, $fieldvalue, $A, $icon_arr)
{
    global $_CONF, $LANG_ADMIN, $LANG_ACCESS;

    $access = SEC_hasAccess($A['owner_id'],$A['group_id'],$A['perm_owner'],$A['perm_group'],$A['perm_members'],$A['perm_anon']);
    if ($access > 0) {
        switch($fieldname) {
            case 'edit':
                if ($A['id'] <> 0) {
                    $retval = "<a href=\"{$_CONF['site_admin_url']}/plugins/archive/index.php?mode=edit&amp;archive={$A['id']}\">{$icon_arr['edit']}</a>";
                } else {
                    $retval = " - ";
                }
                break;
            case 'access':
                if ($access == 3) {
                   $retval = $LANG_ACCESS['edit'];
                } else {
                   $retval = $LANG_ACCESS['readonly'];
                }
                break;
            case 'title':
                $title = stripslashes($A['title']);
                $retval = "<a href=\"{$A['url']}\">$title</a>";
                break;
            default:
                $retval = $fieldvalue;
                break;
        }
    }

    return $retval;
}

/**
* Return a list of all archives
*
* @param    ref     $current_category   currently selected category
* @return   string                      <option> list containing all categories
*
* Note: $current_category will be returned as an empty string when found in the
*       current list of categories and left untouched when it's a new category,
*       i.e. the user selected "Other". This is needed for moderating archive
*       submissions.
*
*/
function archive_getCategoryList (&$current_category)
{
    global $_TABLES, $LANG_AR_ADMIN;

    $retval = '';

    $result = DB_query("SELECT DISTINCT id FROM {$_TABLES['archive']}" . COM_getPermSQL ());
    $nrows = DB_numRows($result);

    $retval = '<option value="' . $LANG_AR_ADMIN[7] . '">'
            . $LANG_AR_ADMIN[7] . '</option>';
    for ($i = 0; $i < $nrows; $i++) {
        $A = DB_fetchArray ($result);
        $category = $A['category'];
        $retval .= '<option value="' . $category . '"';
        if ($category == $current_category) {
            $retval .= ' selected="selected"';
            $current_category = '';
        }
        $retval .= '>' . $category . '</option>';
    }

    return $retval;
}


/**
* Returns the URL of the plugin's icon
*
* @return   string      URL of the icon
*
*/
function plugin_geticon_archive ()
{
    global $_CONF;

    return $_CONF['site_url'] . '/archive/images/archive.gif';
}

/**
* Set template variables
*
* @param    string  $templatename   name of template, e.g. 'header'
* @param    ref     $template       reference of actual template
* @return   void
*
* Note: A plugin should use its name as a prefix for the names of its
* template variables, e.g. 'archive_xxx' and 'lang_archive_xxx'.
* 'button_archive' is an exception, as such a variable existed for header.thtml
* in Geeklog 1.3.11 and earlier, where the archives section was an integral part
* of Geeklog. It is added here for backward-compatibility.
*
*/
function plugin_templatesetvars_archive ($templatename, &$template)
{
    global $LANG_AR;

    if ($templatename == 'header') {
        $template->set_var ('button_archive', $LANG_AR[14]);
    }
}

/**
* Simpler permissions display
*/
function archive_getPermissionsHTML($perm_owner,$perm_group,$perm_members,
                                    $perm_anon,$owner_id,$group_id,$access)
{
    global $LANG_ACCESS, $_CONF, $_TABLES, $LANG_AR_ACCESS;

    $retval = '';

    $perm_templates = new Template($_CONF['path'] . '/plugins/archive/templates');
    $perm_templates->set_file(array('editor'=>'edit_permissions.thtml'));

    $perm_templates->set_var ('owner', $LANG_ACCESS['owner']);
    $perm_templates->set_var ('group', $LANG_ACCESS['group']);
    $perm_templates->set_var ('members', $LANG_ACCESS['members']);
    $perm_templates->set_var ('anonymous', $LANG_ACCESS['anonymous']);
    $perm_templates->set_var ('lang_accessrights', $LANG_ACCESS['accessrights']);
    $perm_templates->set_var ('lang_permissions', $LANG_ACCESS['permissions']);

    $perm_templates->set_var ('name', $LANG_AR_ACCESS['name']);
    $perm_templates->set_var ('can_read', $LANG_AR_ACCESS['can_read']);
    $perm_templates->set_var ('can_edit', $LANG_AR_ACCESS['can_edit']);
    $perm_templates->set_var ('owner_user', $LANG_AR_ACCESS['owner_user']);
    $perm_templates->set_var ('owner_group', $LANG_AR_ACCESS['owner_group']);
    $perm_templates->set_var ('logged_in', $LANG_AR_ACCESS['logged_in']);
    $perm_templates->set_var ('anonymous', $LANG_AR_ACCESS['anonymous']);

    $ownername = COM_getDisplayName ($owner_id);
    $perm_templates->set_var ('owner_name', $ownername);
    $perm_templates->set_var ('owner', $ownername);
    $perm_templates->set_var ('owner_username', DB_getItem($_TABLES['users'], 
                              'username', "uid = {$owner_id}")); 
    $perm_templates->set_var ('link_ownerid', $owner_id);
    $perm_templates->set_var ('group_dropdown', SEC_getGroupDropdown ($group_id, $access));

    // Owner Permissions
    if ($perm_owner >= 2) {
        $perm_templates->set_var ('owner_r_checked',' checked="checked"');
    }
    if ($perm_owner == 3) {
        $perm_templates->set_var ('owner_e_checked',' checked="checked"');
    }
    // Group Permissions
    if ($perm_group >= 2) {
        $perm_templates->set_var ('group_r_checked',' checked="checked"');
    }
    if ($perm_group == 3) {
        $perm_templates->set_var ('group_e_checked',' checked="checked"');
    }
    // Member Permissions
    if ($perm_members == 2) {
        $perm_templates->set_var ('members_checked',' checked="checked"');
    }
    // Anonymous Permissions
    if ($perm_anon == 2) {
        $perm_templates->set_var ('anon_checked',' checked="checked"');
    }

    $perm_templates->parse('output','editor');
    $retval .= $perm_templates->finish($perm_templates->get_var('output'));

    return $retval;
}


/**
* Archive hit counter
*/
function archive_increment_hits ($id)
{
    global $_TABLES;
    DB_query("UPDATE {$_TABLES['archive']} SET hits=hits+1 WHERE id='{$id}'");
    return;
}


/**
* Sets modified date on archive item
* Called when child item (address, text, related item) is modified
* 
* Input:    $id         id of archive item to be updated
* Returns:  nothing
* 
*/
function archive_modified_date($id) {
    global $_TABLES;

    // Update modified date on archive item
    DB_query("UPDATE {$_TABLES['archive']} SET modified=NOW() WHERE id='{$id}'");

    return;
}



// +---------------------------------------------------------------------------+
// | archive Plugin                                                            |
// +---------------------------------------------------------------------------+


/*
* Build selection list
*/
function archive_select_box ($sel = '', $self) {
    global $_CONF, $LANG_AR;
    // root category is 0 in database
    $root = '0';
    // set root value
    $menu = '<option value="0">'.$LANG_AR['root'].'</option>';
    // get option values
    $list = archive_select_box_recursive($menu,$root,$sel,'&nbsp;&nbsp;',$self);
    // return list of options
    return $list;
}


/*
* Build recursive tree
*/
function archive_select_box_recursive (&$menu,$id,$sel,$indent,$self) {
    global $_CONF, $_TABLES;
    $query = DB_QUERY("SELECT id,title 
                       FROM {$_TABLES['archive']} 
                       WHERE (parent='{$id}')" . COM_getPermSQL('AND'));
    while ( list($id,$title) = DB_fetchARRAY($query) ) {
        // don't add the current item to the tree, or any of the current item's own children
        if ($id<>$self) {
            // set selected item
            if ($id==$sel) {
                // yes, selected
                $menu .= '<option value="'.$id.'" SELECTED="SELECTED">'.$indent.$title.'</option>';
            } else {
                // no, not selected
                $menu .= '<option value="'.$id.'">'.$indent.$title.'</option>';
            }
            // Check and see if this category has any sub categories
            if (DB_COUNT($_TABLES['archive'], 'parent', $id) > 0) {
                // yes, call self
                $dum = archive_select_box_recursive (&$menu,$id,$sel,$indent.'&nbsp;&nbsp;',$self);
            }
        }
   }
    return $menu;
}


?>
