<?php

// Reminder: always indent with 4 spaces (no tabs). 
// +---------------------------------------------------------------------------+
// | Archive plugin 1.2 for Geeklog                                            |
// +---------------------------------------------------------------------------+
// | plugins.php                                                               |
// |                                                                           |
// | Include plugin items file for the Geeklog Archive Plugin                  |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2000-2007 by the following authors:                         |
// |                                                                           |
// | Authors: Euan McKay        - info AT heatherengineering DOT com           |
// |          Tony Bibbs        - tony AT tonybibbs DOT com                    |
// |          Mark Limburg      - mlimburg AT users.sourceforge DOT net        |
// |          Jason Whittenburg - jwhitten AT securitygeeks DOT com            |
// |          Dirk Haun         - dirk AT haun-online DOT de                   |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is licensed under the terms of the GNU General Public License|
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                      |
// | See the GNU General Public License for more details.                      |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+



/** ********************  Functions for related items  ******************** **/



// +---------------------------------------------------------------------------+
// | Archive related item functions                                            |
// +---------------------------------------------------------------------------+



/**
* List items that are related to this archive
* This function just loops through each plugin type
*/
function archive_list_related ($parent) {
    global $_CONF, $_TABLES, $LANG_AR, $_AR_CONF;
    $retval = '';

    // Get plugins from database
    $result = DB_query("SELECT pi_name FROM ".$_TABLES['plugins']." WHERE pi_enabled=1");
    $nrows  = DB_numRows ($result);
    // loop through plugins
    if ($nrows > 0) {
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            // check required functions exist and plugin type is enabled in archive plugin
            if (function_exists ('archive_make_'.$A['pi_name'].'_list') && 
                    function_exists ('archive_'.$A['pi_name'].'_item') &&
                    ($_AR_CONF['plugins'][$A['pi_name']]==1)) {
                $retval .= archive_parse_related($parent,$A['pi_name']);
            }
        }
    }
    // also do stories (not plugin)
    if ($_AR_CONF['plugins']['stories']==1) {
        $retval .= archive_parse_related($parent,'story');
    }
    // also do mediagallery thumbnails (because each plugin can only have one automatic type)
    if ((DB_GetItem($_TABLES['plugins'], 'pi_enabled', "pi_name='mediagallery'")==1) && ($_AR_CONF['plugins']['mediagallery']==1)) {
        $retval .= archive_parse_related($parent,'mediagallery_thumb');
    }

    // Return HTML
    return $retval;
}


/**
* Parse the related item data from the plugin requested
*/
function archive_parse_related ($parent, $plugin) {
    global $_CONF, $_TABLES, $LANG_AR, $_AR_CONF;
    $retval = '';

	// Get access rights for the parent archive item from DB
    $result = DB_query("SELECT created,owner_id,group_id,perm_owner,
                         perm_group,perm_members,perm_anon 
                         FROM {$_TABLES['archive']} WHERE id = '{$parent}'");
    $A = DB_fetchArray ($result);
    $access = SEC_hasAccess ($A['owner_id'], $A['group_id'],$A['perm_owner'], 
                             $A['perm_group'], $A['perm_members'],$A['perm_anon']);

    // Get all items from DB
    $result = DB_query("SELECT * FROM {$_TABLES['archive_related']} 
                         WHERE (parent='{$parent}' AND plugin='{$plugin}')
                         ORDER BY sortorder");

    // Set template variables
    $T = new Template($_CONF['path'] . 'plugins/archive/templates/');
    $T->set_file(array ('list' => 'related_list.thtml',
                        'item' => 'related_item.thtml'));
    $T->set_var('site_url', $_CONF['site_url']);
    // Get title to display
    $function = 'archive_'.$plugin.'_name';
    $T->set_var ('plugin', $plugin);

    // Loop through items
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        // Set title
        $T->set_var('lang_archive_related', $function());
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            $function2 = 'archive_'.$plugin.'_item';
            $item = $function2 ($A['relatedid']);
            $img = $item['img'];
            if (!empty($A['title'])) {
                $title = $A['title'];
                $description = $A['description'];
            } else {
                $title = $item['title'];
                $description = '';
            }
            if (isset($img)) {
                $T->set_var ('related_link_item', $img);
                $T->set_var ('related_comment', $title);
            } else {
                $T->set_var ('related_link_item', $title);
                $T->set_var ('related_comment', $description);
            }
            $T->set_var ('related_link', $item['link']);
            // add link to edit if has rights
            if ($access<3) {
                $T->set_var('edit_related_item', '');
            } else {
                if ($_AR_CONF['ajax']==1) {
                    // AJAX style inline editing
                     $edit = '<a href="' . $_CONF['site_url'] . '/archive/index.php?mode=edit&type=related&id=' . $A['relatedid'] . '&parent=' . $parent. '&plugin=' . $plugin . '" onclick="new Ajax.Updater(\'archive_item_' . $A['relatedid'] . '\', \'' . $_CONF['site_url'] . '/archive/index.php?mode=editajax&type=related&id=' . $A['relatedid'] . '&parent=' . $parent . '&plugin=' . $plugin . '\', {asynchronous:true, evalScripts:true }); return false;"><img src="'.$_CONF['site_url'] . '/archive/images/edit.gif"></a>';
                     $delete = '<a href="' . $_CONF['site_url'] . '/archive/index.php?mode=delete&type=related&id=' . $A['relatedid'] . '&plugin=' . $plugin . '" onclick="new Ajax.Updater(\'archive_related_' . $A['plugin'] . '\', \'' . $_CONF['site_url'] . '/archive/index.php?mode=deleteajax&type=related&id=' . $A['relatedid'] . '\', {asynchronous:true, evalScripts:true }); return false;"><img src="'.$_CONF['site_url'] . '/archive/images/delete.gif"></a>';
                     $T->set_var ('item_id', $A['relatedid']);
                } else {
                    //standard type
                    $editurl   = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php'
                               . '?mode=edit&type=related&id=' . $A['relatedid'] . '&parent=' . $parent. '&plugin=' . $plugin);
                    $edit      = '<a href="' . $editurl . '" title="' . $LANG_AR['edit'] . '">' 
                               . '<img src="' . $_CONF['site_url'] . '/archive/images/edit.gif">' 
                               . '</a>';
                    $deleteurl = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php'
                               . '?mode=delete&type=related&id=' . $A['relatedid'] . '&plugin=' . $plugin);
                    $delete    = '<a href="' . $deleteurl . '" title="' . $LANG_AR['delete'] . '">' 
                               . '<img src="' . $_CONF['site_url'] . '/archive/images/delete.gif">' 
                               . '</a>';
                }
                $T->set_var('edit_related_item', $edit);
                $T->set_var('delete_related_item', $delete);
            }
            $T->parse ('archive_related', 'item', true);
        }
   } else {
       // No items to show
        if ($access>2) {
            // Set title and label for editors only
            $T->set_var('lang_archive_related', $function());
            $T->set_var('archive_related', $LANG_AR['no_related']);
        } else {
            $T->set_var('lang_archive_related', '');
            $T->set_var('add_related', '');
            $T->set_var('archive_related', '');
        }
    }

    if ($access>2) {
        // Set add new link for editors only
        if ($_AR_CONF['ajax']==1) {
            // AJAX style inline editing
             $link = '<a href="' . $_CONF['site_url'] . '/archive/index.php?mode=edit&type=related&plugin=' . $plugin . '&parent=' . $parent . '" onclick="new Ajax.Updater(\'new_item_' . $plugin . '\', \'' . $_CONF['site_url'] . '/archive/index.php?mode=editajax&type=related&plugin=' . $plugin . '&parent=' . $parent . '\', {asynchronous:true, evalScripts:true }); return false;"><img src="'.$_CONF['site_url'] . '/archive/images/add.gif"></a>';
        } else {
            //standard type
            $url  = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php'
                  . '?mode=edit&type=related&plugin=' . $plugin . '&parent=' . $parent);
            $link = '<a href="' . $url . '" title="' . $LANG_AR['add_related'] . '">' 
                  . '<img src="' . $_CONF['site_url'] . '/archive/images/add.gif">' 
                  . '</a>';
        }
        $T->set_var('add_related', $link);
    }

    // Parse template
    $T->parse('output', 'list');
    $retval = $T->finish($T->get_var('output'));

    // Return HTML
    return $retval;
}



/**
* Edit archive related item
*/
function archive_edit_related ($parent, $plugin, $relatedid = '', $ajaxmode) 
{
    global $_CONF, $LANG_AR, $LANG_ADMIN, $_AR_CONF, $_TABLES, $_AR_CONF;


    $retval = '';

    // Check at least one ID exists
    if (empty($parent) && empty($relatedid)) {
        if ($_AR_CONF['ajax']==1) {
            // AJAX mode
            return "Insufficient information";
        } else {
            // normal mode
            return COM_refresh ($_CONF['site_url']. '/archive/index.php?msg=4');
        }
    }

    // Get access rights for the parent archive item from DB
    $result = DB_query("SELECT created,owner_id,group_id,perm_owner,
                         perm_group,perm_members,perm_anon 
                         FROM {$_TABLES['archive']} WHERE id='{$parent}'");
    $A = DB_fetchArray ($result);
    $access = 0;
    $access = SEC_hasAccess ($A['owner_id'], $A['group_id'],$A['perm_owner'], 
                             $A['perm_group'], $A['perm_members'],$A['perm_anon']);

    if ($access<3) {
        // no right to edit this archive item
        return COM_refresh ($_CONF['site_url']. '/archive/index.php?msg=8');
    } else {
        // have rights
        // first check we have things to add
        // Get the function from the plugin
        $function = 'archive_make_'.$plugin.'_list';
        $optionlist = $function($relatedid, $parent);
        if ($optionlist==false) {
            // no items to add
            return $LANG_AR['nothingtoadd'];
        }

        // Check ID exists
        if (!empty ($relatedid)) {
            // Existing item, so get data
            $result = DB_query("SELECT * FROM {$_TABLES['archive_related']} 
                                 WHERE relatedid ='{$relatedid}'");
            $A = DB_fetchArray ($result);
            $parent = $A['parent'];
            $plugin = $A['plugin'];
            $sortorder = $A['sortorder'];
            $title = $A['title'];
            $description = $A['description'];
        }

        // Set templates
        $T = new Template($_CONF['path'] . 'plugins/archive/templates/');
        if ($ajaxmode==true) {
            // AJAX, so use minimal template
            $T->set_file('page','related_editor_ajax.thtml');
        } else {
            // normal mode, so use normal template
            $T->set_file('page','related_editor.thtml');
        }

        $T->set_var('site_url', $_CONF['site_url']);
        $T->set_var('layout_url',$_CONF['layout_url']);
        $T->set_var('plugin_name', $LANG_AR['archive']);
        $T->set_var('lang_comment', $LANG_AR['related_editor']);
        $T->set_var('lang_title', $LANG_AR['title']);
        $T->set_var('lang_description', $LANG_AR['description']);
        $T->set_var('lang_sortorder', $LANG_AR['sortorder']);
        $T->set_var('title', $title);
        $T->set_var('description', $description);
        $T->set_var('sortorder', $sortorder);
        $T->set_var('related', $related);
        $T->set_var('parent', $parent);
        $T->set_var('id', $relatedid);

        $T->set_var('lang_related', $LANG_AR['archive_related']);
        $T->set_var('archive_option_list', $optionlist);
        $T->set_var('related_list_name', 'relatedid');
        $T->set_var('plugin_name', 'plugin');
        $T->set_var('plugin_value', $plugin);
        $T->set_var('oldid', $relatedid);

        $T->set_var('lang_save', $LANG_ADMIN['save']);
        $T->set_var('lang_cancel', $LANG_ADMIN['cancel']);

        // Parse output
        $T->parse('output', 'page');
        $retval .= $T->finish($T->get_var('output'));
    }



// Return
    return $retval;

}



/**
* Saves a related item to the archive plugin database
*/
function archive_save_related ($R)
{
    global $_CONF, $_GROUPS, $_TABLES, $_USER, $MESSAGE, $LANG_AR, $_AR_CONF;

    $retval = '';

    $ajaxmode = COM_applyFilter ($R['ajaxmode']);
    $relatedid = COM_applyFilter ($R['relatedid']);
    $oldid = COM_applyFilter ($R['oldid']);
    $parent = COM_applyFilter ($R['parent']);
    $sortorder = COM_applyFilter ($R['sortorder']);
    $title = addslashes (COM_checkHTML (COM_checkWords ($R['title'])));
    $description = addslashes (COM_checkHTML (COM_checkWords ($R['description'])));
    $plugin = addslashes (COM_checkHTML (COM_checkWords ($R['plugin'])));

    // Does user have access permission on the parent item?
    $access = 0;
    $result = DB_query("SELECT owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon 
                         FROM {$_TABLES['archive']} 
                         WHERE id='{$parent}'");
    $A = DB_fetchArray ($result);
    $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'], 
                             $A['perm_group'], $A['perm_members'],$A['perm_anon']);

    // Does the user have permission to edit this item?
    if (($access < 3) || !SEC_inGroup ($A['group_id'])) {
        // No, so tell them so and log it
        $display .= COM_siteHeader('menu', $MESSAGE[30]);
        $display .= COM_startBlock($MESSAGE[30], '',
                            COM_getBlockTemplate('_msg_block', 'header'));
        $display .= $MESSAGE[31];
        $display .= COM_endBlock(COM_getBlockTemplate('_msg_block', 'footer'));
        $display .= COM_siteFooter();
        COM_accessLog("User {$_USER['username']} tried illegally to edit archive $id.");
        echo $display;
        exit;
    } elseif (!empty($relatedid) && !empty($plugin)) {
        // Yes, so save this item
        DB_save ($_TABLES['archive_related'], 
                 'relatedid,parent,plugin,title,description,sortorder', 
                 "'$relatedid','$parent','$plugin','$title','$description','$sortorder'");

        // Check if id was changed
        if (($relatedid<>$oldid) && ($oldid<>'')) {
            DB_Delete ($_TABLES['archive_related'],'relatedid',$oldid);
        }

        // Updatemodified date on parent
        archive_modified_date($parent);
        
        // Update RDF
        COM_rdfUpToDateCheck ('archive', $title, $parent);
        // Set return message
        if ($ajaxmode==true) {
            // AJAX mode, so return section only
            $retval = archive_parse_related ($parent, $plugin);
        } else {
            // otherwise, refresh whole page
            $retval = $_CONF['site_url']. '/archive/index.php?id='.$parent.'&msg=1';
        }
    } else {
        // Missing data
        $retval = $_CONF['site_url']. '/archive/index.php?id='.$parent.'&msg=4';
    }


    // Return result
    return $retval;
}



/**
* Delete an archive related item
*/
function archive_delete_related ($relatedid, $parent, $ajaxmode)
{
    global $_CONF, $_TABLES, $_USER, $_AR_CONF;


    // Get parent ID
    $result = DB_query("SELECT parent,plugin 
                         FROM {$_TABLES['archive_related']} 
                         WHERE relatedid ='{$relatedid}'");
    $A = DB_fetchArray ($result);
    $parent = $A['parent'];
    $plugin = $A['plugin'];

    // Get permission values
    $result = DB_query("SELECT owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon 
                         FROM {$_TABLES['archive']} 
                         WHERE id ='{$parent}'");
    $A = DB_fetchArray ($result);
    $access = 0;
    $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
                             $A['perm_group'], $A['perm_members'], $A['perm_anon']);
    if ($access < 3) {
        // No access rights, so log and return
        COM_accessLog("User {$_USER['username']} tried to delete archive related {$relatedid}.");
        return $_CONF['site_url'] . '/archive/index.php';
    }

    // Delete related item
    DB_delete ($_TABLES['archive_related'], 'relatedid', $relatedid);

    if ($ajaxmode==1) {
        // AJAX mode, so return section only
        $retval = archive_parse_related ($parent, $plugin);
    } else {
        // otherwise, refresh whole page
        $retval = $_CONF['site_url']. '/archive/index.php?id='.$parent.'&msg=9';
    }


    // return a refresh url
    return $retval;
}




/** **************************  Plugin functions  ************************** **/



// +---------------------------------------------------------------------------+
// | Staticpages                                                               |
// +---------------------------------------------------------------------------+



/**
* Returns the plugin name
*/
function archive_staticpages_name()
{
    global $LANG_AR_LABELS;
    return $LANG_AR_LABELS['staticpages'];
}



/**
* Returns a list of all staticpages
*/
function archive_make_staticpages_list($id,$parent)
{
    global $_CONF, $_TABLES, $LANG_AR;
    
    // get permission sql
    $perms = COM_getPermSql();
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    $nrows  = DB_numRows ($result);
    $arr = array();
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
    // Get staticpage title from DB
    $result = DB_query("SELECT sp_id,sp_title FROM {$_TABLES['staticpage']} " .$perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $count = 0;
        $options = '';
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            // check there are new items to add
            if (!in_array($A['sp_id'],$arr)){
                $count = 1;
                if ($id==$A['sp_id']) {
                    $selected = ' SELECTED';
                } else {
                    $selected ='';
                }
                $options .= '<option' . $selected . '  value="' . $A['sp_id'] . '">' 
                          . $A['sp_title'] . '</option>';
            }
        }
        // check if we added any items
        if ($count>0) {
            // yes, so add select tags
            $retval = '<select name="relatedid">' . $options . '</select>';
        } else {
            // no, so return false
            $retval = false;
        }
    } else {
        $retval = false;
    }
   return $retval;
}



/**
* Returns array of title and link to a staticpage given id
*/
function archive_staticpages_item ($id)
{
    global $_CONF, $_TABLES, $LANG_AR;
    $retval = '';
    // Get staticpage title from DB
    $perms = COM_getPermSql('AND');
    $result = DB_query("SELECT sp_title FROM {$_TABLES['staticpage']} WHERE (sp_id='{$id}') ". $perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        $retval['title'] = $A['sp_title'];
        $link = $_CONF['site_url'] . "/staticpages/index.php?page=".$id;
        $retval['link'] = $link;
    } else {
        $retval['title'] = $LANG_AR['itemdeleted'];
        $retval['link'] = "";
    }
   return $retval;
}



// +---------------------------------------------------------------------------+
// | Calendar                                                                  |
// +---------------------------------------------------------------------------+



/**
* Returns the plugin name
*/
function archive_calendar_name()
{
    global $LANG_AR_LABELS;
    return $LANG_AR_LABELS['calendar'];
}



/**
* Returns a list of all calendar events
*/
function archive_make_calendar_list($id,$parent)
{
    global $_CONF, $_TABLES, $LANG_AR;
    
    // get permission sql
    $perms = COM_getPermSql();
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    $nrows  = DB_numRows ($result);
    $arr = array();
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
    $result = DB_query("SELECT eid,title FROM ".$_TABLES['events'] . " " .$perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $count = 0;
        $options = '';
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            if (!in_array($A['eid'],$arr)){
                $count = 1;
                if ($id==$A['eid']) {
                    $selected = ' SELECTED';
                } else {
                    $selected ='';
                }
                $options .= '<option'.$selected.' value="'.$A['eid'].'">'.$A['title'].'</option>';
            }
        }
        // check if we added any items
        if ($count>0) {
            // yes, so add select tags
            $retval = '<select name="relatedid">' . $options . '</select>';
        } else {
            // no, so return false
            $retval = false;
        }
    } else {
        $retval = false;
    }
   return $retval;
}



/**
* Returns array of title and link to an event given id
*/
function archive_calendar_item ($id)
{
    global $_CONF, $_TABLES, $LANG_AR;
    $retval = '';
    // Get event title from DB
    $perms = COM_getPermSql('AND');
    $result = DB_query("SELECT title FROM {$_TABLES['events']} WHERE (eid='{$id}') ". $perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        $retval['title'] = $A['title'];
        $link = $_CONF['site_url'] . "/calendar/event.php?eid=".$id;
        $retval['link'] = $link;
    } else {
        $retval['title'] = $LANG_AR['itemdeleted'];
        $retval['link'] = "";
    }
   return $retval;
}



// +---------------------------------------------------------------------------+
// | MediaGallery Albums                                                       |
// +---------------------------------------------------------------------------+



/**
* Returns the plugin name
*/
function archive_mediagallery_name()
{
    global $LANG_AR_LABELS;
    return $LANG_AR_LABELS['albums'];
}



/**
* Returns a list of all MediaGallery albums
*/
function archive_make_mediagallery_list($id,$parent)
{
    global $_CONF, $_TABLES, $LANG_AR;
    
    // get permission sql
    $perms = COM_getPermSql();
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    $nrows  = DB_numRows ($result);
    $arr = array();
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
    $result = DB_query("SELECT album_id,album_title FROM ".$_TABLES['mg_albums'] . " " .$perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $count = 0;
        $options = '';
        for ($i = 1; $i <= $nrows; $i++) {
            if (!in_array($A['sp_id'],$arr)){
                $count = 1;
                $A = DB_fetchArray ($result);
                if ($id==$A['albumid']) {
                    $selected = ' SELECTED';
                } else {
                    $selected ='';
                }
                $options .= '<option' . $selected . ' value="' . $A['album_id'] . '">'
                         . $A['album_title'] . '</option>';
            }
        }
        // check if we added any items
        if ($count>0) {
            // yes, so add select tags
            $retval = '<select name="relatedid">' . $options . '</select>';
        } else {
            // no, so return false
            $retval = false;
        }
    } else {
        $retval = false;
    }
   return $retval;
}



/**
* Returns array of title and link to a MediaGallery given id
*/
function archive_mediagallery_item ($id)
{
    global $_CONF, $_TABLES, $LANG_AR;
    $retval = '';
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
    // Get album title from DB
    $result = DB_query("SELECT album_title FROM {$_TABLES['mg_albums']} WHERE (album_id='{$id}') ". $perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        $retval['title'] = $A['album_title'];
        $link = $_CONF['site_url'] . "/mediagallery/album.php?aid=".$id;
        $retval['link'] = $link;
    } else {
        $retval['title'] = $LANG_AR['itemdeleted'];
        $retval['link'] = "";
    }
   return $retval;
}



// +---------------------------------------------------------------------------+
// | MediaGallery Images                                                       |
// +---------------------------------------------------------------------------+



/**
* Returns the plugin name
*/
function archive_mediagallery_thumb_name()
{
    global $LANG_AR_LABELS;
    return $LANG_AR_LABELS['images'];
}



/**
* Returns a list of all MediaGallery images
*/
function archive_make_mediagallery_thumb_list($id,$parent)
{
    global $_CONF, $_TABLES, $LANG_AR;
    
    // Get permissions SQL
    $perms = COM_getPermSql('AND');
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    $nrows  = DB_numRows ($result);
    $arr = array();
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
   // Get album title from DB
    $result = DB_query("SELECT t1.media_id AS id,t1.media_title AS title,t3.album_title AS album FROM {$_TABLES['mg_media']} AS t1,  {$_TABLES['mg_media_albums']} AS t2, {$_TABLES['mg_albums']} AS t3 WHERE (t1.media_id=t2.media_id) AND (t2.album_id=t3.album_id)".$perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $count = 0;
        $options = '';
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            if (!in_array($A['id'],$arr)){
                $count = 1;
                if ($id==$A['id']) {
                    $selected = ' SELECTED';
                } else {
                    $selected ='';
                }
                $options .= '<option' . $selected . ' value="' . $A['id'] . '">'
                         . $A['album'] . ' - ' . $A['title'] . '</option>';
            }
        }
        // check if we added any items
        if ($count>0) {
            // yes, so add select tags
            $retval = '<select name="relatedid">' . $options . '</select>';
        } else {
            // no, so return false
            $retval = false;
        }
    } else {
        $retval = false;
    }
   return $retval;
}



/**
* Returns array of title and link to a MediaGallery image given id
*/
function archive_mediagallery_thumb_item ($id)
{
    global $_CONF, $_TABLES, $LANG_AR;
    $retval = '';
    // Get album title from DB
    $perms = COM_getPermSql('AND');
    $result = DB_query("SELECT t1.media_title FROM {$_TABLES['mg_media']} AS t1,  {$_TABLES['mg_media_albums']} AS t2, {$_TABLES['mg_albums']} AS t3 WHERE (t1.media_id=t2.media_id) AND (t2.album_id=t3.album_id) AND (t1.media_id='{$id}') ". $perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        $img = archive_mediagallery_thumbnail($id);
        $retval['img'] = $img['img'];
        $retval['title'] = $img['title'];
        $link = $_CONF['site_url'] . "/mediagallery/media.php?s=".$id;
        $retval['link'] = $link;
    } else {
        $retval['title'] = $LANG_AR['itemdeleted'];
        $retval['link'] = "";
    }
   return $retval;
}



/**
* Returns a thumbnail given an id
* By Mark Evans (MediaGallery)
*/
function archive_mediagallery_thumbnail( $id )
{
    global $_TABLES, $_MG_CONF;

    // check to see if Media Gallery is installed and active...
    if (!function_exists(MG_usage)) {
        return '';
    }

    $retval = array();

    $sql = "SELECT * FROM {$_TABLES['mg_media']} WHERE media_id=" . $id;
    $result = DB_query( $sql );
    $nRows  = DB_numRows( $result );
    if ( $nRows > 0 ) {
        $M = DB_fetchArray($result);

        switch( $M['media_type'] ) {
            case 0 :    // standard image
                $default_thumbnail = 'tn/' . $M['media_filename'][0] . '/' . $M['media_filename']. '.jpg';
                break;
            case 1 :    // video file
                switch ( $M['media_mime_ext'] ) {
                    case 'swf' :
                        $default_thumbnail = 'flash.gif';
                        break;
                    case 'mov' :
                    case 'mp4' :
                        $default_thumbnail = 'quicktime.gif';
                        break;
                    case 'asf' :
                        $default_thumbnail = 'wmp.gif';
                        break;
                    default :
                        $default_thumbnail = 'video.gif';
                        break;
                }
                break;
            case 2 :    // music file
                $default_thumbnail = 'audio.gif';
                break;
            case 4 :    // other files
                switch ($M['media_mime_ext']) {
                    case 'zip' :
                    case 'arj' :
                    case 'rar' :
                    case 'gz'  :
                        $default_thumbnail = 'zip.gif';
                        break;
                    case 'pdf' :
                        $default_thumbnail = 'pdf.gif';
                        break;
                    default :
                        $default_thumbnail = 'generic.gif';
                        break;
                }
                break;
        }

        if ( $M['media_tn_attached'] == 1 ) {
            $media_thumbnail      = $_MG_CONF['site_url']  . '/mediaobjects/tn/'.  $M['media_filename'][0] . '/tn_' . $M['media_filename'] . '.jpg';
            $media_thumbnail_file = $_MG_CONF['path_html'] . 'mediaobjects/tn/'.  $M['media_filename'][0] . '/tn_' . $M['media_filename'] . '.jpg';
        } else {
            $media_thumbnail      = $_MG_CONF['site_url']  . '/mediaobjects/' . $default_thumbnail;
            $media_thumbnail_file = $_MG_CONF['path_html'] . 'mediaobjects/' . $default_thumbnail;
        }

        $media_size        = @getimagesize($media_thumbnail_file);

        if ( $media_size == false ) {
            $default_thumbnail    = 'generic.gif';
            $media_thumbnail      = $_MG_CONF['site_url']  . '/mediaobjects/' . $default_thumbnail;
            $media_thumbnail_file = $_MG_CONF['path_html'] . 'mediaobjects/' . $default_thumbnail;
            $media_size           = @getimagesize($media_thumbnail_file);
        }
        $tn_height = 250;
        if ( $media_size[0] > $media_size[1] ) {
            $ratio = $media_size[0] / $tn_height;
            $newwidth = $tn_height;
            $newheight = round($media_size[1] / $ratio);
        } else {
            $ratio = $media_size[1] / $tn_height;
            $newheight = $tn_height;
            $newwidth = round($media_size[0] / $ratio);
        }
        $media_dim = 'width="' . $newwidth . '" height="' . $newheight . '"';

        $img = '<img src="' .$media_thumbnail . '" ' . $media_dim . ' border="0" alt="' . strip_tags(COM_stripslashes($M['media_title'])) . '" title="' . strip_tags(COM_stripslashes($M['media_title'])) . '"/>';
        $link = $_MG_CONF['site_url'] . '/media.php?f=0' . '&amp;s=' . $M['media_id'] ;
        $title = strip_tags(COM_stripslashes($M['media_title']));
        $id    = $M['media_id'];
        $retval['id'] = $id;
        $retval['title'] = $title;
        $retval['img'] = $img;
        $retval['link'] = $link;
    } else {
        $retval['id'] = $id;
        $retval['title'] = '';
        $retval['img'] = '';
        $retval['link'] = '';
    }

    return $retval;
}



// +---------------------------------------------------------------------------+
// | Links                                                                     |
// +---------------------------------------------------------------------------+



/**
* Returns the plugin name
*/
function archive_links_name()
{
    global $LANG_AR_LABELS;
    return $LANG_AR_LABELS['links'];
}



/**
* Returns a list of all Links
*/
function archive_make_links_list($id,$parent)
{
    global $_CONF, $_TABLES, $LANG_AR;
    
    // get permission sql
    $perms = COM_getPermSql();
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    $nrows  = DB_numRows ($result);
    $arr = array();
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
    // Get link title from DB
    $result = DB_query("SELECT lid,title FROM ".$_TABLES['links'] . " " .$perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $count = 0;
        $options = '';
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            if (!in_array($A['lid'],$arr)){
                $count = 1;
                if ($id==$A['lid']) {
                    $selected = ' SELECTED';
                } else {
                    $selected ='';
                }
                $options .= '<option'.$selected.' value="'.$A['lid'].'">'.$A['title'].'</option>';
            }
        }
         // check if we added any items
         if ($count>0) {
             // yes, so add select tags
             $retval = '<select name="relatedid">' . $options . '</select>';
         } else {
             // no, so return false
             $retval = false;
         }
     } else {
         $retval = false;
     }
    return $retval;
}



/**
* Returns array of title and link to a Link given id
*/
function archive_links_item ($id)
{
    global $_CONF, $_TABLES, $LANG_AR;
    $retval = '';
    // Get link title from DB
    $perms = COM_getPermSql('AND');
    $result = DB_query("SELECT title FROM {$_TABLES['links']} WHERE (lid='{$id}') ". $perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        $retval['title'] = $A['title'];
        $link = $_CONF['site_url'] . "/links/portal.php?what=link&item=".$id;
        $retval['link'] = $link;
    } else {
        $retval['title'] = $LANG_AR['itemdeleted'];
        $retval['link'] = "";
    }
   return $retval;
}



// +---------------------------------------------------------------------------+
// | Forum                                                                     |
// +---------------------------------------------------------------------------+



/**
* Returns the plugin name
*/
function archive_forum_name()
{
    global $LANG_AR_LABELS;
    return $LANG_AR_LABELS['forum'];
}



/**
* Returns a list of all forums
*/
function archive_make_forum_list($id,$parent)
{
    global $_CONF, $_TABLES, $LANG_AR;
    
    // get permission sql
    $perms = COM_getPermSql();
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    $nrows  = DB_numRows ($result);
    $arr = array();
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
    // Get forum title from DB
    $result = DB_query("SELECT forum_id,forum_name FROM {$_TABLES['gf_forums']} {$perms}");
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $count = 0;
        $options = '';
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            if (!in_array($A['forum_id'],$arr)){
                $count = 1;
                if ($id==$A['forum_id']) {
                    $selected = ' SELECTED';
                } else {
                    $selected ='';
                }
                $options .= '<option' . $selected . ' value="' . $A['forum_id'] . '">'
                         . $A['forum_name'] . '</option>';
            }
        }
        // check if we added any items
        if ($count>0) {
            // yes, so add select tags
            $retval = '<select name="relatedid">' . $options . '</select>';
        } else {
            // no, so return false
            $retval = false;
        }
    } else {
        $retval = false;
    }
   return $retval;
}



/**
* Returns array of title and link to a forum given id
*/
function archive_forum_item ($id)
{
    global $_CONF, $_TABLES, $LANG_AR;
    $retval = '';
    // Get forum title from DB
    $result = DB_query("SELECT forum_name FROM {$_TABLES['gf_forums']} WHERE (forum_id ='{$id}')");
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        $retval['title'] = $A['forum_name'];
        $link = $_CONF['site_url'] . "/forum/index.php?forum=".$id;
        $retval['link'] = $link;
    } else {
        $retval['title'] = $LANG_AR['itemdeleted'];
        $retval['link'] = "";
    }
   return $retval;
}



// +---------------------------------------------------------------------------+
// | File Management                                                           |
// +---------------------------------------------------------------------------+



/**
* Returns the plugin name
*/
function archive_filemgmt_name()
{
    global $LANG_AR_LABELS;
    return $LANG_AR_LABELS['filemgmt'];
}



/**
* Returns a list of all files
*/
function archive_make_filemgmt_list($id,$parent)
{
    global $_CONF, $_TABLES, $LANG_AR;
    
    // get permission sql
    $perms = COM_getPermSql();
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    $nrows  = DB_numRows ($result);
    $arr = array();
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
    // Get file title from DB
    $result = DB_query("SELECT lid,title FROM " . $_FM_TABLES['filemgmt_filedetail'] . " " .$perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $count = 0;
        $options = '';
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            if (!in_array($A['lid'],$arr)){
                $count = 1;
                if ($id==$A['lid']) {
                    $selected = ' SELECTED';
                } else {
                    $selected ='';
                }
                $options .= '<option'.$selected.' value="'.$A['lid'].'">'.$A['title'].'</option>';
            }
        }
        // check if we added any items
        if ($count>0) {
            // yes, so add select tags
            $retval = '<select name="relatedid">' . $options . '</select>';
        } else {
            // no, so return false
            $retval = false;
        }
    } else {
        $retval = false;
    }
    return $retval;
}



/**
* Returns array of title and link to a file given id
*/

function archive_filemgmt_item ($id)
{
    global $_CONF, $_FM_TABLES, $LANG_AR;
    $retval = '';
    // Get file title from DB
    $perms = COM_getPermSql('AND');
    $result = DB_query("SELECT title FROM {$_FM_TABLES['filemgmt_filedetail']} WHERE (lid='{$id}') ". $perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        $retval['title'] = $A['title'];
        $link = $_CONF['site_url'] . "/filemgmt/singlefile.php?lid=".$id;
        $retval['link'] = $link;
    } else {
        $retval['title'] = $LANG_AR['itemdeleted'];
        $retval['link'] = "";
    }
   return $retval;
}



// +---------------------------------------------------------------------------+
// | Stories                                                                   |
// +---------------------------------------------------------------------------+



/**
* Returns the plugin name
*/
function archive_story_name()
{
    global $LANG_AR_LABELS;
    return $LANG_AR_LABELS['stories'];
}



/**
* Returns a list of all stories
*/
function archive_make_story_list($id,$parent)
{
    global $_CONF, $_TABLES, $LANG_AR;
    
    // get permission sql
    $perms = COM_getPermSql();
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    $nrows  = DB_numRows ($result);
    $arr = array();
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
    // Get file title from DB
    $result = DB_query("SELECT sid,title FROM " . $_TABLES['stories'] . " " .$perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $count = 0;
        $options = '';
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            if (!in_array($A['sid'],$arr)){
                $count = 1;
                if ($id==$A['sid']) {
                    $selected = ' SELECTED';
                } else {
                    $selected ='';
                }
                $options .= '<option'.$selected.' value="'.$A['sid'].'">'.$A['title'].'</option>';
            }
        }
        // check if we added any items
        if ($count>0) {
            // yes, so add select tags
            $retval = '<select name="relatedid">' . $options . '</select>';
        } else {
            // no, so return false
            $retval = false;
        }
    } else {
        $retval = false;
    }
    return $retval;
}



/**
* Returns array of title and link to a story given id
*/
function archive_story_item ($id)
{
    global $_CONF, $_TABLES, $LANG_AR;
    $retval = '';
    // Get file title from DB
    $perms = COM_getPermSql('AND');
    $result = DB_query("SELECT title FROM {$_TABLES['stories']} WHERE (sid='{$id}') ". $perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        $retval['title'] = $A['title'];
        $link = $_CONF['site_url'] . "/article.php?story=".$id;
        $retval['link'] = $link;
    } else {
        $retval['title'] = $LANG_AR['itemdeleted'];
        $retval['link'] = "";
    }
   return $retval;
}



// +---------------------------------------------------------------------------+
// | Archive                                                                   |
// +---------------------------------------------------------------------------+



/**
* Returns the plugin name
*/
function archive_archive_name()
{
    global $LANG_AR_LABELS;
    return $LANG_AR_LABELS['archive'];
}



/**
* Returns a list of all archive items
*/
function archive_make_archive_list($id,$parent)
{
    global $_CONF, $_TABLES, $LANG_AR, $_AR_CONF;


    // get permission sql
    $perms = COM_getPermSql();
    // Get items that are already linked
    $existing = DB_query("SELECT relatedid 
                           FROM {$_TABLES['archive_related']} 
                           WHERE parent='{$parent}' ");
    $nrows  = DB_numRows ($result);
    $arr = array();
    while ($current = DB_fetchArray ($existing)) {
        if ($id<>$current['relatedid']) {
            $arr[] = $current['relatedid'];
        }
    }
   // Get title from DB
    $result = DB_query("SELECT id,title FROM ".$_TABLES['archive'] . " " .$perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $count = 0;
        $options = '';
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            if (!in_array($A['id'],$arr)){
                $count = 1;
                if ($id==$A['id']) {
                    $selected = ' SELECTED';
                } else {
                    $selected ='';
                }
                $options .= '<option'.$selected.' value="'.$A['id'].'">'.$A['title'].'</option>';
            }
        }
        // check if we added any items
        if ($count>0) {
            // yes, so add select tags
            $retval = '<select name="relatedid">' . $options . '</select>';
        } else {
            // no, so return false
            $retval = false;
        }
    } else {
        $retval = false;
    }


   return $retval;
}



/**
* Returns array of title and link to an archive given id
*/
function archive_archive_item ($id)
{
    global $_CONF, $_TABLES, $LANG_AR;
    $retval = '';
    // Get archive title from DB
    $perms = COM_getPermSql('AND');
    $result = DB_query("SELECT title FROM {$_TABLES['archive']} WHERE (id='{$id}') ". $perms);
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        $retval['title'] = $A['title'];
        $link = $_CONF['site_url'] . "/archive/index.php?id=".$id;
        $retval['link'] = $link;
    } else {
        $retval['title'] = $LANG_AR['itemdeleted'];
        $retval['link'] = "";
    }
   return $retval;
}



?>
