<?php

// Reminder: always indent with 4 spaces (no tabs). 
// +---------------------------------------------------------------------------+
// | Archive plugin 1.2 for Geeklog                                            |
// +---------------------------------------------------------------------------+
// | index.php                                                                 |
// |                                                                           |
// | This is the main page for the Archive plugin for Geeklog                  |
// +---------------------------------------------------------------------------+
// | Based on the Universal Plugin and prior work by the following authors:    |
// |                                                                           |
// | Copyright (C) 2002-2007 by the following authors:                         |
// |                                                                           |
// | Authors: Euan McKay        - info AT heatherengineering DOT com           |
// |          Tony Bibbs        - tony AT tonybibbs DOT com                    |
// |          Tom Willett       - tom AT pigstye DOT net                       |
// |          Blaine Lang       - blaine AT portalparts DOT com                |
// |          Dirk Haun         - dirk AT haun-online DOT de                   |
// |          Vincent Furia     - vinny01 AT users DOT sourceforge DOT net     |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

require_once('../lib-common.php');

$display = '';


// +---------------------------------------------------------------------------+
// | Archive main archive item functions                                       |
// +---------------------------------------------------------------------------+

// archive_top_page        - list all archives (used for top page only)
// archive_show_archive    - show a single archive
// archive_list_archives   - show all child archives of an archive item as list
// archive_edit_archive    - edit a single archive
// archive_save_archive    - save a single archive
// archive_delete_archive  - delete a single archive


/**
* List all archive items for top page
* If multilanguage operation is enabled, will list only items with ids ending 
* with the current language code
* 
* Input:    nothing
* Returns:  HTML        HTML page to display
* 
*/
function archive_top_page()
{
    global $_CONF, $_AR_CONF, $_TABLES, $LANG_ADMIN, $LANG_AR, $LANG_ACCESS, $_IMAGE_TYPE;


    $retval = '';

    if ($_AR_CONF['archiveloginrequired'] && !SEC_inGroup('Logged-in Users')) {
        $retval = COM_refresh ($_CONF['site_url'] . "/index.php?msg=8&plugin=archive");
        return $retval;
    }

    // Multilanguage support
    if ($_AR_CONF['multilanguage_support']) {
        $sql = COM_getLangSQL('id', 'AND', $_TABLES['archive']);
    } else {
        $sql = '';
    }
    $sql = "SELECT * FROM " . $_TABLES['archive'] . " WHERE (parent='0') ". $sql;

    // Get archives from DB
    $result = DB_query($sql);

    // Set template variables
    $T = new Template($_CONF['path'] . 'plugins/archive/templates/');
    $T->set_file(array ('list' => 'archive_list.thtml',
                        'item' => 'archive_item.thtml'));
    $T->set_var('site_url', $_CONF['site_url']);
    $T->set_var('plugin_name', $LANG_AR['archive']);
    $T->set_var('description', $LANG_AR['archive_list']);

    // Set link to create new archive if has rights
    if (SEC_hasRights('archive.edit')) {
        $url = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php?mode=edit');
        $link = '<a href="' . $url . '" title="' . $LANG_AR['create_archive'] . '">' 
                 . '<img src="'.$_CONF['site_url'] . '/archive/images/add.gif" alt="' . $LANG_AR['create_archive'] . '">'
                 . '</a>';
        $T->set_var('create_archive', $link);
    } else {
        $T->set_var('create_archive', '');
    }

    // Loop through archives
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        for ($i = 1; $i <= $nrows; $i++) {
            $A = DB_fetchArray ($result);
            // replace linefeeds with <br /> tags
            $linefeed = "\r";
            $description =  str_replace($linefeed, "<BR />", stripslashes ($A['description']));
            $T->set_var ('archive_title', stripslashes ($A['title']));
            $T->set_var ('archive_description', PLG_replaceTags($description));
            $T->set_var ('archive_id', $A['id']);
            // Set link to edit archive if has rights
            if (SEC_hasRights('archive.edit')) {
                $url       = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php'
                           . '?mode=edit&id=' . $A['id']);
                $edit      = '<a href="' . $url . '" title="' . $LANG_AR['edit'] . '">' 
                           . '<img src="'.$_CONF['site_url'] . '/archive/images/edit.gif">' 
                           . '</a>';
                $deleteurl = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php' 
                           . '?mode=delete&type=archive&id=' . $A['id']);
                $delete    = '<a href="' . $deleteurl . '" title="' . $LANG_AR['delete'] . '">' 
                           . '<img src="' . $_CONF['site_url'] . '/archive/images/delete.gif">' 
                           . '</a>';
                $T->set_var('edit_archive_item', $edit);
                $T->set_var('delete_archive_item', $delete);
            } else {
                $T->set_var('edit_archive_item', '');
            }
            $T->parse ('page_content', 'item', true);
        }
   } else {
        $T->set_var ('page_content', $LANG_AR['no_archives']);
    }

    // Parse template
    $T->parse('output', 'list');
    $retval = $T->finish($T->get_var('output'));


    // Return HTML
    return $retval;

}



/**
* Show a single archive page
*/
function archive_show_archive($id)
{
    global $_CONF, $_AR_CONF, $_TABLES, $_USER, $LANG_AR;


    $retval ='';

    // Get item data
    $result = DB_query("SELECT * FROM {$_TABLES['archive']} 
                        WHERE (id='{$id}') " . COM_getPermSQL('AND'));

    // Check item exists
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $A = DB_fetchArray ($result);
        // Item exists, so set language strings to template
        $T = new Template($_CONF['path'] . 'plugins/archive/templates/');
        $T->set_file(array ('page' => 'archive.thtml'));
        $T->set_var('site_url', $_CONF['site_url']);
        $T->set_var('plugin_name', $LANG_AR['archive']);
        $T->set_var('description', $LANG_AR['archive_list']);
        $T->set_var('lang_modified', $LANG_AR['archive_modified']);
        $T->set_var('lang_created', $LANG_AR['archive_created']);
        $T->set_var('lang_hits', $LANG_AR['archive_hits']);

        // Set data to template
        // replace linefeeds with <br /> tags
        $linefeed = "\r";
        $description =  str_replace($linefeed, "<BR />", stripslashes ($A['description']));
        $T->set_var ('archive_title', stripslashes ($A['title']));
        $T->set_var ('archive_description', PLG_replaceTags($description));
        $T->set_var ('archive_id', $A['id']);
        $T->set_var ('archive_modified', $A['modified']);
        $T->set_var ('archive_created', $A['created']);
        $T->set_var ('archive_hits', $A['hits']);

        // get access rights
        $access = SEC_hasAccess ($A['owner_id'], $A['group_id'],$A['perm_owner'], 
                   $A['perm_group'], $A['perm_members'],$A['perm_anon']);

        // add link to edit if has rights
        if ($access<3) {
            $T->set_var('edit_archive_item', '');
        } else {
            $editurl   = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php'
                       . '?mode=edit&type=archive&id=' . $A['id'] . '&return_id=' . $A['id']);
            $edit      = '<a href="' . $editurl . '" title="' . $LANG_AR['edit'] . '">' 
                       . '<img src="' . $_CONF['site_url'] . '/archive/images/edit.gif">' 
                       . '</a>';
            $deleteurl = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php'
                       . '?mode=delete&type=archive&id=' . $A['id'] . '&return_id=' . $A['id']);
            $delete    = '<a href="' . $deleteurl.'" title="' . $LANG_AR['delete'] . '">' 
                       . '<img src="' . $_CONF['site_url'] . '/archive/images/delete.gif">' 
                       . '</a>';
            $T->set_var('edit_archive_item', $edit);
            $T->set_var('delete_archive_item', $delete);
        }

        // Get associated items
        $T->set_var ('archive_archives', archive_list_archives($id));
        $T->set_var ('archive_texts', archive_list_texts($id, $_AR_CONF['ajax']));
        $T->set_var ('archive_addresses', archive_list_addresses($id, $_AR_CONF['ajax']));
        $T->set_var ('archive_related', archive_list_related($id, $_AR_CONF['ajax']));

        // Set link to parent
        $url    = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php?id=' . $A['parent']);
        $link   = '<a href="' . $url . '" title="' . $LANG_AR['archive_parent'] . '">' 
                . '<img src="' . $_CONF['site_url'] . '/archive/images/up.gif">'
                . '</a>';
        $T->set_var ('archive_parent', $link);

        // Parse template
        $T->parse('output', 'page');
        $retval = $T->finish($T->get_var('output'));
    } else {
        // No such item, so return to top page with error message
        return COM_refresh ($_CONF['site_url']. '/archive/index.php?msg=3');
    }

    // Increment hit count
    archive_increment_hits ($id);


    // Return data
    return $retval;
}



/**
* Lists all the child archive items for an archive item
*/
function archive_list_archives ($parent) {
    global $_CONF, $_TABLES, $LANG_AR, $_AR_CONF;
    $retval = '';

    // Get access rights for the parent archive item from DB
    $result = DB_query("SELECT created,owner_id,group_id,perm_owner,
                         perm_group,perm_members,perm_anon 
                         FROM {$_TABLES['archive']} WHERE id = '{$parent}'");
    $A = DB_fetchArray ($result);
    $itemaccess = SEC_hasAccess ($A['owner_id'], $A['group_id'],$A['perm_owner'], 
                                 $A['perm_group'], $A['perm_members'],$A['perm_anon']);

    // Get all archives from DB
    $query = "SELECT id,title,description,
              owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon
              FROM {$_TABLES['archive']} 
              WHERE (parent='{$parent}')";
    $result = DB_query($query);
    // Set template variables
    $T = new Template($_CONF['path'] . 'plugins/archive/templates/');
    $T->set_file(array ('list' => 'item_list.thtml',
                        'item' => 'item_item.thtml'));
    $T->set_var('site_url', $_CONF['site_url']);

    // Loop through archives
    $nrows  = DB_numRows ($result);
    if ($nrows > 0) {
        $T->set_var('lang_archive_archives', $LANG_AR['archive_archives']);
        for ($i = 1; $i <= $nrows; $i++) {
            $B = DB_fetchArray ($result);
            $T->set_var ('archive_title', $B['title']);
            // Shorten description if too long
            if (strlen($A['description'])>30) {
                $B['description'] = substr($A['description'],0,30)."...";
            }
            $T->set_var ('archive_description', $A['description']);
            $T->set_var ('archive_id', $B['id']);
            // add link to edit if has rights
            $access = SEC_hasAccess ($B['owner_id'], $B['group_id'],$B['perm_owner'],
                                     $B['perm_group'], $B['perm_members'],$B['perm_anon']);
            if ($access<3) {
                $T->set_var('edit_archive_item', '');
            } else {
                $editurl   = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php'
                           . '?mode=edit&type=archive&id=' . $B['id'] . '&return_id='.$parent);
                $edit      = '<a href="' . $editurl . '" title="' . $LANG_AR['edit'] . '">' 
                           . '<img src="' . $_CONF['site_url'] . '/archive/images/edit.gif">' 
                           . '</a>';
                $deleteurl = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php'
                           . '?mode=delete&type=archive&id=' . $B['id']);
                $delete    = '<a href="' . $deleteurl . '" title="' . $LANG_AR['delete'] . '">' 
                           . '<img src="' . $_CONF['site_url'] . '/archive/images/delete.gif">' 
                           . '</a>';
                    $T->set_var('edit_archive_item', $edit);
                    $T->set_var('delete_archive_item', $delete);
            }
            $T->parse ('archive_archives', 'item', true);
        }
   } else {
       // Set link to create new archive if has rights
        if ($itemaccess>2) {
            $T->set_var('lang_archive_archives', $LANG_AR['archive_archives']);
            $T->set_var('archive_archives', $LANG_AR['no_child_archives']);
        } else {
            $T->set_var('lang_archive_archives', '');
            $T->set_var('add_archive', '');
            $T->set_var('archive_archives', '');
        }
    }

    // Set link to create new archive if has rights
     if ($itemaccess>2) {
         $url  = COM_buildUrl ($_CONF['site_url'] . '/archive/index.php'
               . '?mode=edit&type=archive&parent=' . $parent . '&return_id='.$parent);
         $link = '<a href="' . $url.'" title="' . $LANG_AR['add_archive'] . '">' 
               . '<img src="' . $_CONF['site_url'] . '/archive/images/add.gif">' 
               . '</a>';
         $T->set_var('add_archive', $link);
     }

    // Parse template
    $T->parse('output', 'list');
    $retval = $T->finish($T->get_var('output'));

    // Return HTML
    return $retval;
}



/**
* Shows the archive editor
*/
function archive_edit_archive ($parent,$id,$return_id) 
{
    global $_CONF, $_TABLES, $LANG_ACCESS, $LANG_ADMIN, $_USER, $_GROUPS, $LANG_AR, $_AR_CONF;

    $retval = '';

    // Set templates
    $T = new Template($_CONF['path'] . 'plugins/archive/templates/');
    $T->set_file('page','archive_editor.thtml');
    $T->set_var('site_url', $_CONF['site_url']);
    $T->set_var('site_admin_url', $_CONF['site_admin_url']);
    $T->set_var('layout_url',$_CONF['layout_url']);
    $T->set_var('plugin_name', $LANG_AR['archive']);
    $T->set_var('lang_explanation', $LANG_AR['archive_editor']);
    $T->set_var('lang_title', $LANG_AR['title']);
    $T->set_var('lang_id', $LANG_AR['id']);
    $T->set_var('lang_parent', $LANG_AR['parent']);
    $T->set_var('lang_description', $LANG_AR['description']);

    // ID exists so must be editing an existing item
    if (!empty($id)) {
        $result = DB_query("SELECT * FROM {$_TABLES['archive']} WHERE id ='$id'");
        $A = DB_fetchArray($result);
        $access = SEC_hasAccess($A['owner_id'],$A['group_id'],$A['perm_owner'],
                                $A['perm_group'],$A['perm_members'],$A['perm_anon']);

        // Check they are allowed to edit this item if it already exists
        if ($access == 0 OR $access == 2) {
            $retval .= COM_startBlock($LANG_LINKS_ADMIN[16], '',
                               COM_getBlockTemplate('_msg_block', 'header'));
            $retval .= $LANG_LINKS_ADMIN[17];
            $retval .= COM_endBlock(COM_getBlockTemplate('_msg_block', 'footer'));
            COM_accessLog("User {$_USER['username']} tried to illegally edit archive $id.");
            return $retval;
        }
        $old_id = $A['id'];

    // No ID, so this is a new item. Set default values
    } else {
        $A['id'] = COM_makesid();
        $A['title'] = '';
        $A['description'] = '';
        $A['hits'] = 0;
        $A['owner_id'] = $_USER['uid'];
        $old_id = '';
        if (isset ($_GROUPS['archive Admin'])) {
            $A['group_id'] = $_GROUPS['archive Admin'];
        } else {
            $A['group_id'] = SEC_getFeatureGroup ('archive.edit');
        }
        SEC_setDefaultPermissions ($A, $_AR_CONF['default_permissions']);
        // check we're not creating a child of an existing item
        if (!$parent) {
            $A['parent'] = 0;
        } else {
            $A['parent'] = $parent;
        }
    }
    $parentdd = archive_select_box ($A['parent'], $A['id']);
    $T->set_var('parent_dropdown', $parentdd);

    // Set values to form
    $T->set_var('title', stripslashes ($A['title']));
    $T->set_var('id', $A['id']);
    $T->set_var('old_id', $old_id);
    $T->set_var('hits', $A['hits']);
    $T->set_var('return_id', $return_id);
    $T->set_var('description', stripslashes ($A['description']));
    $T->set_var('hits', $A['hits']);
    $T->set_var('parent', $A['parent']);

    // Set permissions editor to form
    $T->set_var('permissions_editor', archive_getPermissionsHTML($A['perm_owner'],$A['perm_group'],
                $A['perm_members'],$A['perm_anon'],$A['owner_id'],$A['group_id'],$access));
    $T->set_var('lang_save', $LANG_ADMIN['save']);
    $T->set_var('lang_cancel', $LANG_ADMIN['cancel']);

    // Parse output
    $T->parse('output', 'page');
    $retval .= $T->finish($T->get_var('output'));

    // Return
    return $retval;

}



/**
* Saves an item to the archive plugin database
*/
function archive_save_archive ($R)
{
    global $_CONF, $_GROUPS, $_TABLES, $_USER, $MESSAGE, $LANG_AR;
    $retval = '';

    $id        = COM_applyFilter($R['id']);
    $old_id    = COM_applyFilter($R['old_id']);
    $return_id = COM_applyFilter($R['return_id']);
    $hits      = COM_applyFilter($R['hits']);

    // Check ID exists (should, but the user may have deleted it)
    if (empty ($id)) {
        // Check if there is an old ID hidden in the form
        if (empty ($old_id)) {
            // No, so create a new one
            $id = COM_makeSid ();
        } else {
            // Yes, so use the old ID
            $id = $old_id;
        }
    }

    // This is wrong. I know there is a better way somewhere in existing Geeklog code...
    $owner_id = COM_applyFilter($R['owner_id']);
    $group_id = COM_applyFilter($R['group_id']);

    // Convert array values to numeric permission values
    if (is_array($R['perm_owner']) OR is_array($R['perm_group']) 
                OR is_array($R['perm_members']) OR is_array($R['perm_anon'])) {
        list($perm_owner,$perm_group,$perm_members,$perm_anon) =
                SEC_getPermissionValues($R['perm_owner'], $R['perm_group'], 
                        $R['perm_members'], $R['perm_anon']);
    }

    $title       = addslashes (COM_checkHTML (COM_checkWords ($R['title'])));
    $description = addslashes (COM_checkHTML (COM_checkWords ($R['description'])));
    $parent      = COM_applyFilter($R['parent']);

    // Set permissions value for user
    $access = 0;
    // Is there an existing item with the old ID?
    if (DB_count($_TABLES['archive'], 'id', $old_id) > 0) {
        // Yes, so use saved access rights and set a flag
        $update = true;
        $result = DB_query("SELECT created,owner_id,group_id,
                             perm_owner,perm_group,perm_members,perm_anon 
                             FROM {$_TABLES['archive']} 
                             WHERE id='{$old_id}'");
        $A = DB_fetchArray ($result);
        $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
                                 $A['perm_group'], $A['perm_members'], $A['perm_anon']);
        $created = "'" . $A['created'] . "'";
    } else {
        // No, so use provided access rights
        $access = SEC_hasAccess ($owner_id, $group_id, $perm_owner, $perm_group,
                                 $perm_members, $perm_anon);
    }

    // Does the user have permission to edit this item?
    if (($access < 3) || !SEC_inGroup ($group_id)) {
        // No, no permission so tell them so and log it
        $display .= COM_siteHeader('menu', $MESSAGE[30]);
        $display .= COM_startBlock($MESSAGE[30], '',
                            COM_getBlockTemplate('_msg_block', 'header'));
        $display .= $MESSAGE[31];
        $display .= COM_endBlock(COM_getBlockTemplate('_msg_block', 'footer'));
        $display .= COM_siteFooter();
        COM_accessLog("User {$_USER['username']} tried to illegally submit or edit archive $id.");
        echo $display;
        exit;
    } elseif (!empty($title) && !empty($description)) {
        // Yes, has permission so proceed
        // Check if the ID has changed
        if (!empty($id) && !empty($old_id) && $id<>$old_id) {
            // ID changed so delete existing item
            DB_delete ($_TABLES['archive'], 'id', $old_id);
            // now update all child items
            DB_query("UPDATE {$_TABLES['archive']} 
                       SET parent='{$id}' 
                       WHERE parent='{$old_id}'");
            DB_query("UPDATE {$_TABLES['archive_text']} 
                       SET parent='{$id}' 
                       WHERE parent='{$old_id}'");
            DB_query("UPDATE {$_TABLES['archive_address']} 
                       SET parent='{$id}' 
                       WHERE parent='{$old_id}'");
            DB_query("UPDATE {$_TABLES['archive_related']} 
                       SET parent='{$id}' 
                       WHERE parent='{$old_id}'");
            DB_query("UPDATE {$_TABLES['archive_related']} 
                       SET relatedid='{$id}' 
                       WHERE relatedid='{$old_id}'");
        }
        if (!$update) {
            // new item so set created date/time
            $created = "NOW()";
        }
        // Save this item
        DB_save ($_TABLES['archive'],
                 'id,parent,title,description,created,modified,hits,
                  owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon', 
                 "'$id','$parent','$title','$description',$created,NOW(),'$hits','$owner_id',
                  '$group_id','$perm_owner','$perm_group','$perm_members','$perm_anon'");

        // Update RDF
        COM_rdfUpToDateCheck ('archive', $title, $id);

        // make URL to return to
        $retval = $_CONF['site_url']. '/archive/index.php?id='.$return_id.'&msg=1';
    } else {
        // Missing data
        $retval = $_CONF['site_url']. '/archive/index.php?msg=4';
    }
    
    // Return result
    return $retval;
}






/**
* Delete an archive item
* Will not allow delete if child archive items exist
* Will allow delete if related items, addresses and texts exist
* Will also delete these items from the database
* 
* Input:    $archive    id of archive item to be deleted
* Returns:  URL         URL to refresh with appended message
*                       message will be one of the following:
*                       1) insufficient access rights
*                       2) child archive items exist so cannot delete
*                       3) item was deleted
* 
*/

function archive_delete_archive ($archive) {
    global $_CONF, $_TABLES, $_USER;

    // Check permissions on item to be deleted
    $sql = "SELECT parent,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon 
            FROM {$_TABLES['archive']} 
            WHERE id ='$archive'";
    $result = DB_query($sql);
    $A = DB_fetchArray ($result);
    $parent = $A['parent'];
    $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
            $A['perm_group'], $A['perm_members'], $A['perm_anon']);

    // Allow delete if they have access rights
    if ($access < 3) {
        COM_accessLog("User {$_USER['username']} tried to illegally delete archive $archive.");
        return $_CONF['site_url'] . '/archive/index.php?id='.$archive;
    }

    // Do we have child archives? We allow to delete if there are no child archives,
    // but we don't mind about other items (related items, texts, etc.)
    $result = DB_query("SELECT id FROM {$_TABLES['archive']} WHERE parent ='$archive'");
    if (DB_numRows($result) > 0) {
        // don't allow delete - refresh page with message
        return $_CONF['site_url'] . '/archive/index.php?id='.$archive.'&msg=6';
    }

    // Delete archive item and any related items etc.
    DB_delete($_TABLES['archive'], 'id', $archive);
    DB_delete($_TABLES['archive_text'], 'parent', $archive);
    DB_delete($_TABLES['archive_address'], 'parent', $archive);
    DB_delete($_TABLES['archive_related'], 'parent', $archive);

    // Set return URL
    return $_CONF['site_url']. '/archive/index.php?id='.$parent.'&msg=2';
}


// +---------------------------------------------------------------------------+
// | Main                                                                      |
// +---------------------------------------------------------------------------+


$mode = '';
if (isset ($_REQUEST['mode'])) {
    $mode = COM_applyFilter($_REQUEST['mode']);
}
$type = '';
if (isset ($_REQUEST['type'])) {
    $type = COM_applyFilter($_REQUEST['type']);
}
$ajaxmode = '';
if (isset ($_REQUEST['ajaxmode'])) {
    $ajaxmode = COM_applyFilter($_REQUEST['ajaxmode']);
}
$plugin = '';
if (isset ($_REQUEST['plugin'])) {
    $plugin = COM_applyFilter($_REQUEST['plugin']);
}
$id = '';
if (isset ($_REQUEST['id'])) {
    $id = COM_applyFilter($_REQUEST['id']);
}
$old_id = '';
if (isset ($_REQUEST['old_id'])) {
    $old_id = COM_applyFilter($_REQUEST['old_id']);
}
$return_id = '';
if (isset ($_REQUEST['return_id'])) {
    $return_id = COM_applyFilter($_REQUEST['return_id']);
}
$parent = '0';
if (isset ($_REQUEST['parent'])) {
    $parent = COM_applyFilter($_REQUEST['parent']);
}
$msg = '';
if (isset ($_REQUEST['msg'])) {
    $msg = COM_applyFilter($_REQUEST['msg']);
}

$content = '';

// case delete item ************************************************************

if ($mode == 'delete') {
    if ($type=='text') {
        $url = archive_delete_text($id, false);
    } elseif ($type=='address') {
        $url = archive_delete_address($id, false);
    } elseif ($type=='related') {
        $url = archive_delete_related($id, $parent, 0);
    } else {
        $url = archive_delete_archive($id, $parent, false);
    }
    echo COM_Refresh ($url);

} else if ($mode == 'deleteajax') {
    if ($type=='text') {
        $content = archive_delete_text($id, true);
    } elseif ($type=='address') {
        $content = archive_delete_address($id, true);
    } elseif ($type=='related') {
        $content = archive_delete_related($id, $parent, 1);
    } else {
        // we should never get here
        $content = "Error";
    }
    $display = $content;



// case save item **************************************************************

} else if (($mode == $LANG_ADMIN['save']) && !empty ($LANG_ADMIN['save'])) {
    if ($type=='text') {
        // save a text item
        $retval = archive_save_text($_REQUEST);
        if ($ajaxmode==1) {
            // AJAX mode, so return section only
            $display = $retval;
        } else {
            // otherwise, refresh whole page
            echo COM_Refresh($retval);
        }
    } elseif ($type=='address') {
        // save an address item
        $retval = archive_save_address($_REQUEST);
        if ($ajaxmode==1) {
            // AJAX mode, so return section only
            $display = $retval;
        } else {
            // otherwise, refresh whole page
            echo COM_Refresh($retval);
        }
    } elseif ($type=='related') {
        // save a related item
        $retval = archive_save_related($_REQUEST);
        if ($ajaxmode==1) {
            // AJAX mode, so return section only
            $display = $retval;
        } else {
            // otherwise, refresh whole page
            echo COM_Refresh($retval);
        }
    } else {
        $url = archive_save_archive($_REQUEST);
        echo COM_Refresh($url);
    }


// case edit item **************************************************************

} else if ($mode == 'edit') {
    if ($type=='text') {
        $content = archive_edit_text ($parent,$id,false);
    } elseif ($type=='address') {
        $content = archive_edit_address ($parent,$id,false);
    } elseif ($type=='related') {
        $content = archive_edit_related ($parent,$plugin,$id,false);
    } else {
        $content = archive_edit_archive($parent, $id, $return_id);
    }
    $display  = COM_siteHeader($_AR_CONF['show_left_menu'], $LANG_AR[1]);
    $display .= $content;
    $display .= COM_siteFooter();

} else if ($mode == 'editajax') {
    if ($type=='text') {
        $content = archive_edit_text ($parent,$id,true);
    } elseif ($type=='address') {
        $content = archive_edit_address ($parent,$id,true);
    } elseif ($type=='related') {
        $content = archive_edit_related ($parent, $plugin, $id, true);
    } else {
        // we should never get here
        $content = "Error";
    }
    $display = $content;


// case cancel *****************************************************************

} elseif ($mode=='cancel_ajax') {
    if ($type=='text') {
        $content = archive_list_texts($parent, true);
    } elseif ($type=='address') {
        $content = archive_list_addresses($parent, $plugin);
    } elseif ($type=='related') {
        $content = archive_parse_related($parent, $plugin);
    } else {
        $content = archive_show_archive($id);
    }
    $display = $content;

} elseif ($mode==$LANG_ADMIN['cancel']) {
    if (!empty($return_id)) {
        $content .= archive_show_archive($return_id);
    } elseif (!empty($parent)) {
        $content .= archive_show_archive($parent);
    } else {
        $content .= archive_top_page();
    }
    $display = COM_siteHeader($_AR_CONF['show_left_menu'], $LANG_AR_ADMIN[11]);
    $display .= $content;
    $display .= COM_siteFooter();

// no mode *********************************************************************

} else {
    if ($msg > 0) {
        $content .= COM_showMessage($msg, 'archive');
    }
    if (!empty($id)) {
        $content .= archive_show_archive($id);
    } else {
        $content .= archive_top_page();
    }

    $display  = COM_siteHeader($_AR_CONF['show_left_menu'], $LANG_AR_ADMIN[11]);
    $display .= $content;
    $display .= COM_siteFooter();
}


// display page ****************************************************************


echo $display;

?>
